# The fritzing-app repo does not contain a tag for v0.9.10
# The app commit we're using is dated 2022-05-14
%define git      29c2cede3a0475ed770db1ee502fdebf6bf3a23d
%define gitparts 4713511c894cb2894eae505b9307c6555afcc32c

%define rel 2

Name:           fritzing
Version:        0.9.10
Release:        %mkrel %{rel}
Summary:        Electronic Design Automation software; from prototype to product
License:        GPLv3+, CC-BY-SA
Group:          Sciences/Other
Url:            https://fritzing.org/
Source0:        https://github.com/fritzing/fritzing-app/archive/%{git}/%{name}-app-%{git}.tar.gz
# The fritzing-parts repository no longer uses git tags for marking releases.
# There is a "release_0.9.6" branch in the repository, though.
# Take the latest commit from that branch (as of 2022-05-10).
Source2:        https://github.com/fritzing/fritzing-parts/archive/%{gitparts}/%{name}-parts-%{gitparts}.tar.gz
# Taken from fedora until a fix for issue 3796
Source3:        parts.db
# Mageia-specific patch to disable internal auto-updating feature
#Patch0:         0000-disable-autoupdate.patch
# Use the system quazip library instead of the bundled one and
# upgrade to Quazip Qt5 V1.x
Patch1:         0001-unbundle-quazip.patch
# Remove references to example sketches that use twitter4j library
Patch2:         0002-remove-twitter4j.patch
# use system libgit2
Patch3:         fritzing-0.9.10-use-system-libgit2.patch

BuildRequires:  pkgconfig(libgit2)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(ngspice)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5SerialPort)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  cmake(QuaZip-Qt5)
BuildRequires:  boost-devel
BuildRequires:  desktop-file-utils
BuildRequires:  qttools5

# mga#24115
Requires:       qt5-database-plugin-sqlite

%description
Fritzing is an open-source initiative to support designers, artists,
researchers and hobbyists to take the step from physical prototyping
to actual product. It is in the spirit of Processing and Arduino which
allows users to document their Arduino and other electronic-based
prototypes, and to create a PCB layout for manufacturing.

%prep
%setup -q -n %{name}-app-%{git}
tar -xf %{SOURCE2}
mv %{name}-parts-%{gitparts}/ parts/

# Remove some GitHub-specific files
rm -rf .github || true
rm -rf parts/.github || true

rm -rf src/lib/quazip

# The TwitterSaurus examples use (a bundled) twitter4j library, whose license
# is incompatible with Mageia.
rm -f sketches/core/Fritzing\ Creator\ Kit\ DE+EN/creator-kit-*/Fritzing/TwitterSaurus.fzz
rm -f sketches/core/Fritzing\ Creator\ Kit\ DE+EN/creator-kit-*/Processing/twitter4j-core-2.2.5.jar
rm -rf sketches/core/Fritzing\ Creator\ Kit\ DE+EN/creator-kit-*/Processing/TwitterSaurus*
rm -f sketches/core/obsolete/TwitterSaurus.fzz

# Remove a <url> entry which causes the appstream file to fail validation.
sed -e '/<url type="forum">/d' -i 'org.fritzing.Fritzing.appdata.xml'

%autopatch -p1

%build
CXXFLAGS="%{optflags}"
%qmake_qt5
%make_build

# FIXME Generate the parts database
# https://github.com/fritzing/fritzing-app/issues/3796
#./Fritzing -platform minimal -f ./parts -db ./parts/parts.db

%install
%make_install INSTALL_ROOT=%{buildroot}

ln -s %{_bindir}/Fritzing %{buildroot}%{_bindir}/%{name}
cp -f %{buildroot}%{_mandir}/man1/Fritzing.1 %{buildroot}%{_mandir}/man1/fritzing.1

# FIXME Generate the parts database
install -m 0644 %{SOURCE3} %{buildroot}%{_datadir}/%{name}/parts/

%files
%doc README.md
%license LICENSE.GPL2 LICENSE.GPL3 LICENSE.CC-BY-SA
%{_bindir}/Fritzing
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/org.%{name}.Fritzing.desktop
%{_metainfodir}/org.%{name}.Fritzing.appdata.xml
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/mime/packages/%{name}.xml
%{_mandir}/man?/*


%changelog
* Thu Mar 23 2023 daviddavid <daviddavid> 0.9.10-2.mga9
+ Revision: 1950168
- drop no more needed by the project Qt5WebKit build dependency

* Mon Nov 21 2022 daviddavid <daviddavid> 0.9.10-1.mga9
+ Revision: 1909652
- new version: 0.9.10
- remove bundled twitter4j library (license is incompatible)

* Wed Nov 09 2022 papoteur <papoteur> 0.9.6-5.mga9
+ Revision: 1904887
- rebuild for qt5-quazip 1.3

* Tue Apr 05 2022 umeabot <umeabot> 0.9.6-4.mga9
+ Revision: 1845364
- Mageia 9 Mass Rebuild

* Mon Jan 03 2022 wally <wally> 0.9.6-3.mga9
+ Revision: 1766335
- rebuild for libgit2 1.3.0

* Wed May 19 2021 daviddavid <daviddavid> 0.9.6-2.mga9
+ Revision: 1725545
- switch to new quazip 1.0
- workaround the parts.db file until an upstream fix
- generate the parts database (parts.db)

* Sun Mar 14 2021 daviddavid <daviddavid> 0.9.6-1.mga9
+ Revision: 1702638
- new version: 0.9.6
- drop quazip5 patch (build against system quazip library - now supported upstream)
- rebase libgit2 and port-remaining-of-the-scripts-to-python3 patches

* Wed Dec 30 2020 luigiwalser <luigiwalser> 0.9.4-4.git20191201.mga8
+ Revision: 1666238
- rebuild for libgit2

* Wed Dec 16 2020 umeabot <umeabot> 0.9.4-3.git20191201.mga8
+ Revision: 1658485
- Rebuild for new Qt5

* Fri Jul 24 2020 daviddavid <daviddavid> 0.9.4-2.git20191201.mga8
+ Revision: 1608631
- rebuild for new libgit2 1.0.1
- add support for libgit2 >= 1.0

* Wed Feb 19 2020 daviddavid <daviddavid> 0.9.4-1.git20191201.mga8
+ Revision: 1544395
- new version: 0.9.4 (CD-498)
- remove merged upstream patches
- add patch to port remaining of the scripts to python3
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Mon May 06 2019 alexl <alexl> 0.9.3b-6.git20181017.mga7
+ Revision: 1396417
- fix desktop file
- update Russian translation

* Sat Apr 20 2019 wally <wally> 0.9.3b-5.git20181017.mga7
+ Revision: 1393750
- rebuild for libgit2 0.28.1

* Sat Mar 30 2019 umeabot <umeabot> 0.9.3b-4.git20181017.mga7
+ Revision: 1381787
- Qt5 Rebuild

* Wed Jan 02 2019 daviddavid <daviddavid> 0.9.3b-3.git20181017.mga7
+ Revision: 1348742
- add patch to fix the logic to find the parts directory (mga#24114)

* Wed Jan 02 2019 daviddavid <daviddavid> 0.9.3b-2.git20181017.mga7
+ Revision: 1348730
- add missing dependency on qt5-database-plugin-sqlite (mga#24115)

* Wed Oct 17 2018 zezinho <zezinho> 0.9.3b-1.git20181017.mga7
+ Revision: 1321869
- shorter release

* Wed Oct 17 2018 zezinho <zezinho> 0.9.3b-0.git624187517fc89062a4e83d6c08d306863c0d4ec7.mga7
+ Revision: 1321496
- no release since 2016 so new version from today git 624187517fc89062a4e83d6c08d306863c0d4ec7

* Sun Sep 23 2018 umeabot <umeabot> 0.9.2-0.beta20150403.9.mga7
+ Revision: 1297787
- Mageia 7 Mass Rebuild

* Mon May 09 2016 luigiwalser <luigiwalser> 0.9.2-0.beta20150403.8.mga6
+ Revision: 1011760
- add patch from fedora to fix build with quazip
- use upstream .desktop file
- rebuild for quazip

* Sun Feb 14 2016 umeabot <umeabot> 0.9.2-0.beta20150403.7.mga6
+ Revision: 960196
- Mageia 6 Mass Rebuild

* Sat Jul 04 2015 alexl <alexl> 0.9.2-0.beta20150403.6.mga6
+ Revision: 849903
- enable external quazip (thanks to anaselli for fix)

* Fri Jul 03 2015 alexl <alexl> 0.9.2-0.beta20150403.5.mga6
+ Revision: 849760
- version 0.9.2b
- switch to qt5
- disable external quazip because of segfaults with open/save
- add additional fritzing man page
- update disable-autoupdate.patch

* Tue Jan 06 2015 alexl <alexl> 0.8.7-0.beta20140124.4.mga5
+ Revision: 808817
- changed GenericName in desktop file

* Wed Oct 15 2014 umeabot <umeabot> 0.8.7-0.beta20140124.3.mga5
+ Revision: 749053
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.8.7-0.beta20140124.2.mga5
+ Revision: 679360
- Mageia 5 Mass Rebuild

* Mon Apr 14 2014 alexl <alexl> 0.8.7-0.beta20140124.1.mga5
+ Revision: 613998
- imported package fritzing

